"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.captureAllRequests = exports.watchScreen = void 0;
function watchScreen(elementReference, screenCode, options) {
    var startTime = Date.now();
    var endTime = null;
    var observer = new IntersectionObserver(function (entries) {
        entries.forEach(function (entry) {
            if (entry.isIntersecting) {
                startTime = Date.now();
            }
            else {
                endTime = Date.now();
            }
        });
    }, __assign({}, options));
    observer.observe(elementReference);
    return function () {
        observer.unobserve(elementReference);
        if (endTime !== null) {
            var timeOnScreen = endTime - startTime;
            fetch('http://localhost/gravar-metrica', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json'
                },
                body: JSON.stringify({
                    tipo: 1,
                    tag: screenCode,
                    nomeTela: options === null || options === void 0 ? void 0 : options.screenName,
                    tempoTela: timeOnScreen,
                    codigoSistema: '0001',
                })
            })
                .then(function (response) {
                if (response.ok) {
                    console.debug('Tempo na tela enviado com sucesso para a API.');
                }
                else {
                    console.debug('Erro ao enviar tempo na tela para a API:', response.statusText);
                }
            })
                .catch(function (error) {
                console.error('Erro ao enviar tempo na tela para a API:', error);
            });
        }
    };
}
exports.watchScreen = watchScreen;
function captureAllRequests() {
    function interceptXMLHttpRequest() {
        var originalOpen = XMLHttpRequest.prototype.open;
        var originalSend = XMLHttpRequest.prototype.send;
        XMLHttpRequest.prototype.open = function (method, url) {
            var args = [];
            for (var _i = 2; _i < arguments.length; _i++) {
                args[_i - 2] = arguments[_i];
            }
            this._method = method;
            this._url = url;
            return originalOpen.apply(this, __spreadArray([method, url], args, true));
        };
        XMLHttpRequest.prototype.send = function (data) {
            var startTime = performance.now();
            this.addEventListener('load', function () {
                var endTime = performance.now();
                var responseTime = endTime - startTime;
                fetch('http://localhost/gravar-metrica', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify({
                        tipo: 2,
                        statusRequisicao: this.status,
                        metodo: this._method,
                        url: this._url,
                        tempoResposta: responseTime.toFixed(2),
                        resposta: this.responseText,
                        requisicao: data,
                        codigoSistema: '0001',
                    })
                })
                    .then(function (response) {
                    if (response.ok) {
                        console.debug('Requisicao enviada com sucesso para a API.');
                    }
                    else {
                        console.debug('Erro ao dados da requisicao para a API:', response.statusText);
                    }
                })
                    .catch(function (error) {
                    console.debug('Erro ao dados da requisicao para a API:', error);
                });
            });
            return originalSend.apply(this, [data]);
        };
    }
    if (typeof window !== 'undefined') {
        interceptXMLHttpRequest();
    }
}
exports.captureAllRequests = captureAllRequests;
